/*
 * Copyright (c) 2010-2011, The MiCode Open Source Community (www.micode.net)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.micode.notes.data;

import android.net.Uri;

public class Notes {
    // 定义权限标识符
    public static final String AUTHORITY = "micode_notes";
    public static final String TAG = "Notes";

    // 定义文件类型常量
    public static final int TYPE_NOTE     = 0; // 普通便签
    public static final int TYPE_FOLDER   = 1; // 文件夹
    public static final int TYPE_SYSTEM   = 2; // 系统文件夹

    /**
     * 以下ID是系统文件夹的标识符
     * {@link Notes#ID_ROOT_FOLDER } 是默认文件夹
     * {@link Notes#ID_TEMPARAY_FOLDER } 是未分类便签的文件夹
     * {@link Notes#ID_CALL_RECORD_FOLDER} 用于存储通话记录
     */
    public static final int ID_ROOT_FOLDER = 0; // 根文件夹
    public static final int ID_TEMPARAY_FOLDER = -1; // 临时文件夹
    public static final int ID_CALL_RECORD_FOLDER = -2; // 通话记录文件夹
    public static final int ID_TRASH_FOLER = -3; // 回收站文件夹

    // 定义Intent的额外数据键
    public static final String INTENT_EXTRA_ALERT_DATE = "net.micode.notes.alert_date"; // 提醒日期
    public static final String INTENT_EXTRA_BACKGROUND_ID = "net.micode.notes.background_color_id"; // 背景颜色ID
    public static final String INTENT_EXTRA_WIDGET_ID = "net.micode.notes.widget_id"; // 小部件ID
    public static final String INTENT_EXTRA_WIDGET_TYPE = "net.micode.notes.widget_type"; // 小部件类型
    public static final String INTENT_EXTRA_FOLDER_ID = "net.micode.notes.folder_id"; // 文件夹ID
    public static final String INTENT_EXTRA_CALL_DATE = "net.micode.notes.call_date"; // 通话日期

    // 定义小部件类型常量
    public static final int TYPE_WIDGET_INVALIDE      = -1; // 无效小部件
    public static final int TYPE_WIDGET_2X            = 0; // 2x小部件
    public static final int TYPE_WIDGET_4X            = 1; // 4x小部件

    // 定义数据常量类
    public static class DataConstants {
        public static final String NOTE = TextNote.CONTENT_ITEM_TYPE; // 便签内容类型
        public static final String CALL_NOTE = CallNote.CONTENT_ITEM_TYPE; // 通话记录内容类型
    }

    /**
     * 查询所有便签和文件夹的Uri
     */
    public static final Uri CONTENT_NOTE_URI = Uri.parse("content://" + AUTHORITY + "/note");

    /**
     * 查询数据的Uri
     */
    public static final Uri CONTENT_DATA_URI = Uri.parse("content://" + AUTHORITY + "/data");

    // 定义便签和文件夹的列常量
    public interface NoteColumns {
        public static final String ID = "_id"; // 唯一ID
        public static final String PARENT_ID = "parent_id"; // 父级ID
        public static final String CREATED_DATE = "created_date"; // 创建日期
        public static final String MODIFIED_DATE = "modified_date"; // 修改日期
        public static final String ALERTED_DATE = "alert_date"; // 提醒日期
        public static final String SNIPPET = "snippet"; // 文件夹名称或便签内容
        public static final String WIDGET_ID = "widget_id"; // 小部件ID
        public static final String WIDGET_TYPE = "widget_type"; // 小部件类型
        public static final String BG_COLOR_ID = "bg_color_id"; // 背景颜色ID
        public static final String HAS_ATTACHMENT = "has_attachment"; // 是否有附件
        public static final String NOTES_COUNT = "notes_count"; // 文件夹中便签数量
        public static final String TYPE = "type"; // 文件类型（文件夹或便签）
        public static final String SYNC_ID = "sync_id"; // 同步ID
        public static final String LOCAL_MODIFIED = "local_modified"; // 是否本地修改
        public static final String ORIGIN_PARENT_ID = "origin_parent_id"; // 移动到临时文件夹前的原始父级ID
        public static final String GTASK_ID = "gtask_id"; // Google任务ID
        public static final String VERSION = "version"; // 版本号
    }

    // 定义数据的列常量
    public interface DataColumns {
        public static final String ID = "_id"; // 唯一ID
        public static final String MIME_TYPE = "mime_type"; // MIME类型
        public static final String NOTE_ID = "note_id"; // 所属便签的ID
        public static final String CREATED_DATE = "created_date"; // 创建日期
        public static final String MODIFIED_DATE = "modified_date"; // 修改日期
        public static final String CONTENT = "content"; // 数据内容
        public static final String DATA1 = "data1"; // 通用数据列1
        public static final String DATA2 = "data2"; // 通用数据列2
        public static final String DATA3 = "data3"; // 通用数据列3
        public static final String DATA4 = "data4"; // 通用数据列4
        public static final String DATA5 = "data5"; // 通用数据列5
    }

    // 定义文本便签类
    public static final class TextNote implements DataColumns {
        public static final String MODE = DATA1; // 文本模式（1: 待办清单模式, 0: 普通模式）
        public static final int MODE_CHECK_LIST = 1; // 待办清单模式
        public static final String CONTENT_TYPE = "vnd.android.cursor.dir/text_note"; // 文本便签内容类型
        public static final String CONTENT_ITEM_TYPE = "vnd.android.cursor.item/text_note"; // 文本便签项目类型
        public static final Uri CONTENT_URI = Uri.parse("content://" + AUTHORITY + "/text_note"); // 文本便签的Uri
    }

    // 定义通话记录便签类
    public static final class CallNote implements DataColumns {
        public static final String CALL_DATE = DATA1; // 通话日期
        public static final String PHONE_NUMBER = DATA3; // 电话号码
        public static final String CONTENT_TYPE = "vnd.android.cursor.dir/call_note"; // 通话记录内容类型
        public static final String CONTENT_ITEM_TYPE = "vnd.android.cursor.item/call_note"; // 通话记录项目类型
        public static final Uri CONTENT_URI = Uri.parse("content://" + AUTHORITY + "/call_note"); // 通话记录便签的Uri
    }
}